echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v g-ir-compiler) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v valac) == "" ]] && echo "Installing vala" && extension --install vala && echo "Finished vala"
fi
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v gtkdocize) == "" ]] && echo "Installing gtk_doc" && extension --install gtk_doc && echo "Finished gtk_doc"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v xfce4-kiosk-query) == "" ]]; then
	echo "libxfce4util" 								>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "libxfce4util" 								>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
